@@ -5,14 +5,14 @@ from .fitting.global_bdata_fitter import global_bdata_fitter
 from .fitting.fit_bdata import fit_bdata
 from .fitting.minuit import minuit
 
-import logging, os, sys, argparse, subprocess, requests, json
+import logging, os, sys, argparse, subprocess, requests, json, code
 from logging.handlers import RotatingFileHandler
 from textwrap import dedent
 from pkg_resources import parse_version 
 from tkinter import messagebox
 
-__all__ = ['gui','fitting','backend']
-__version__ = '4.6.5'
+__all__ = ['gui','fitting','backend','test']
+__version__ = '4.7.0'
 __author__ = 'Derek Fujimoto'
 logger_name = 'bfit'
 icon_path = os.path.join(os.path.dirname(__file__),'data','icon.gif')
@@ -50,6 +50,13 @@ def main():
                         dest='debug', 
                         action='store_true', 
                         default=False)
+    
+    # no gui mode
+    parser.add_argument("-c", "--commandline", 
+                        help='Run in command line mode', 
+                        dest='commandline', 
+                        action='store_true', 
+                        default=False)
 
     # parse
     args = parser.parse_args()
@@ -111,7 +118,10 @@ def main():
         pass
     
     # start bfit --------------------------------------------------------------
-    bfit(testfn)
+    b = bfit(testfn, args.commandline)
+    if args.commandline:
+        code.interact(local=locals())
+        print('bfit object set to variable "b"')
     
 
     
