@@ -38,6 +38,7 @@ from bfit.gui.calculator_nqr_B0 import calculator_nqr_B0
 from bfit.gui.calculator_nmr_B1 import calculator_nmr_B1
 from bfit.gui.calculator_nmr_atten import calculator_nmr_atten
 from bfit.gui.popup_drawstyle import popup_drawstyle
+from bfit.gui.popup_deadtime import popup_deadtime
 from bfit.gui.popup_redraw_period import popup_redraw_period
 from bfit.gui.popup_terminal import popup_terminal
 from bfit.gui.popup_units import popup_units
@@ -98,7 +99,7 @@ class bfit(object):
         Data Fields:
             asym_dict_keys: asym calc and draw types
             data:           dict of fitdata objects for drawing/fitting, keyed by run #
-            draw_style:     draw window types # stack, redraw, new
+            draw_style:     StringVar, draw window types # stack, redraw, new
             draw_components:list of titles for labels, options to export, draw.
             draw_fit:       BooleanVar, if true draw fits after fitting
             draw_ppm:       BoolVar for drawing as ppm shift
@@ -136,6 +137,7 @@ class bfit(object):
     norm_alph_diff_time = 0.1   # number of seconds to take average over when 
                                 # normalizing alpha diffusion runs
     legend_max_draw = 8 # max number of items to draw before removing the legend
+    deadtime_1f = 0        # deadtime in s, for counter corrections in 1f/1w/1n modes
     
     # track settings for use_nbm
     use_nbm_settings = {'default':False,
@@ -306,11 +308,12 @@ class bfit(object):
         bnqr_data_dir = os.getcwd()
         
     # ======================================================================= #
-    def __init__(self, testfn=None):
+    def __init__(self, testfn=None, commandline=False):
         """
             testfn: if not none, expect a function handle with input self to run
                     automate setting parameters, button pushes, etc for rapid 
                     testing
+            commandline:    if True leave user in interactive mode with no mainloop running
         """
         # logging
         self.logger = logging.getLogger(logger_name)
@@ -428,6 +431,9 @@ class bfit(object):
         self.nbm_dict[''].set(False)
         self.nbm_dict['1n'].set(True)
         
+        # deadtime slr
+        self.deadtime_slr = BooleanVar()
+        self.deadtime_slr.set(False)
         
         # Menu bar options ----------------------------------------------------
         root.option_add('*tearOff', FALSE)
@@ -456,6 +462,8 @@ class bfit(object):
         
         # Settings cascade commands
         menu_settings.add_cascade(menu=menu_settings_dir, label='Data directory')
+        menu_settings.add_command(label='Deadtime correction', 
+                command=self.set_deadtime)
         menu_settings.add_command(label='Drawing style', 
                 command=self.set_draw_style)
         menu_settings.add_command(label='Histograms', 
@@ -546,8 +554,12 @@ class bfit(object):
                 variable=self.draw_standardized_res, selectcolor=colors.selected)
         menu_draw.add_checkbutton(label="Draw 1f as PPM shift", \
                 variable=self.draw_ppm, selectcolor=colors.selected)
+        
+        menu_draw.add_separator()
         menu_draw.add_checkbutton(label="Use NBM in asymmetry", \
                 variable=self.nbm_dict[''], selectcolor=colors.selected)        
+        menu_draw.add_checkbutton(label="Use SLR deadtime correction", \
+                variable=self.deadtime_slr, selectcolor=colors.selected)        
         
         # Fitting minimizers
         menu_mini = Menu(menubar, title='Minimizer')
@@ -617,9 +629,13 @@ class bfit(object):
         
         # logging 
         self.logger.debug('Initialization success. Starting mainloop.')
-    
+        
         # runloop
-        self.root.mainloop()
+        if commandline:
+            root.update_idletasks()
+            root.update()
+        else:
+            self.root.mainloop()
     
     # ======================================================================= #
     def __del__(self):
@@ -1666,7 +1682,8 @@ class bfit(object):
         state = self.fetch_files.check_state.get()
         self.fetch_files.check_state.set(not state)
         self.fetch_files.check_all()
-    def set_draw_style(self):       popup_drawstyle(wref.proxy(self))
+    def set_deadtime(self):          popup_deadtime(wref.proxy(self))
+    def set_draw_style(self):        popup_drawstyle(wref.proxy(self))
     def set_histograms(self, *a):    popup_set_histograms(wref.proxy(self))
     def set_focus_tab(self, idn, *a): self.notebook.select(idn)
     def set_nbm(self, mode):
